==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_ping/com/clustercontrol/ping/factory/AddMonitorPing.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.ping.factory;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.monitor.run.factory.AddMonitorNumericValueType;
import com.clustercontrol.ping.bean.PingCheckInfo;
import com.clustercontrol.ping.ejb.entity.MonitorPingInfoUtil;
import com.clustercontrol.ping.ejb.session.MonitorPingRunManagementHome;

/**
 * ping監視情報を登録するクラス<BR>
 *
 * @version 2.0.0
 * @since 2.0.0
 */
public class AddMonitorPing extends AddMonitorNumericValueType{
	
	protected static Log m_log = LogFactory.getLog( AddMonitorPing.class );
	
	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
	 */
	@Override
	public boolean addCheckInfo() throws CreateException, NamingException{
		
		// ping監視情報を設定
		PingCheckInfo ping = m_monitorInfo.getPingCheckInfo();
		
		MonitorPingInfoUtil.getLocalHome().create(
				m_monitorInfo.getMonitorTypeId(),
				m_monitorInfo.getMonitorId(),
				ping.getRunCount(),
				ping.getRunInterval(),
				ping.getTimeout());
		
		return true;
	}
	
	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#getJndiName()
	 */
	@Override
	public String getJndiName() {
		return MonitorPingRunManagementHome.JNDI_NAME;
	}
}

==> hinemos_src-4.0.0.tar.gz: HinemosManager/src_ping/com/clustercontrol/ping/factory/AddMonitorPing.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.ping.factory;

import javax.ejb.CreateException;
import javax.naming.NamingException;

import com.clustercontrol.commons.scheduler.TriggerScheduler;
import com.clustercontrol.monitor.run.factory.AddMonitor;
import com.clustercontrol.monitor.run.factory.AddMonitorNumericValueType;
import com.clustercontrol.ping.bean.PingCheckInfo;
import com.clustercontrol.ping.ejb.entity.MonitorPingInfoUtil;

/**
 * ping監視情報を登録するクラス<BR>
 *
 * @version 4.0.0
 * @since 2.0.0
 */
public class AddMonitorPing extends AddMonitorNumericValueType{

	/* (非 Javadoc)
	 * @see com.clustercontrol.monitor.run.factory.AddMonitor#addCheckInfo()
	 */
	@Override
	protected boolean addCheckInfo() throws CreateException, NamingException{

		// ping監視情報を設定
		PingCheckInfo ping = m_monitorInfo.getPingCheckInfo();

		MonitorPingInfoUtil.getLocalHome().create(
				m_monitorInfo.getMonitorId(),
				ping.getRunCount(),
				ping.getRunInterval(),
				ping.getTimeout());

		return true;
	}

	/**
	 * スケジュール実行の遅延時間を返します。
	 */
	@Override
	protected int getDelayTime() {
		return AddMonitor.getDelayTimeBasic(m_monitorInfo);
	}

	/**
	 * スケジュール実行種別を返します。
	 */
	@Override
	protected String getTriggerType() {
		return TriggerScheduler.TRIGGER_TYPE_SIMPLE;
	}
}
